#!/usr/bin/env python3
# -*- mode: Python; encoding: utf-8; indent-offset: 4; autowrap: nil -*-

import socket

import cmk.utils.version as cmk_version
import cmk.gui.config as config
from cmk.gui.i18n import _
from cmk.gui.globals import html

from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    PasswordSpec,
	FixedValue,
    HTTPUrl,
)

from cmk.gui.plugins.wato import (
    notification_parameter_registry,
    NotificationParameter,
    passwordstore_choices,
    HTTPProxyReference,
    IndividualOrStoredPassword,
)

from cmk.gui.plugins.wato.utils import (
    PasswordFromStore,)

@notification_parameter_registry.register
class NotificationParameterVonage(NotificationParameter):
    @property
    def ident(self):
        return "vonage"

    @property
    def spec(self):
        return Transform(
            Dictionary(
                title=_("Create notification with the following parameters"),
				optional_keys=[ "from_name" ],
                elements=[
                 ("api_key",
                   TextAscii(
                     title=_("API Key"),
                     help=_("The API Key for your Vonage account"),
                     allow_empty=False,
                 )),
                 ("api_secret",
                   IndividualOrStoredPassword(
                     title=_("API Secret"),
                     help=_("The Vonage API Secret associated to the given key"),
                     allow_empty=False,
                 )),
                 ("from_name",
                   TextAscii(
                     title=_("Sender Name"),
                     help=_("A short name to be displayed as the 'From' name. <br/>" +
							"The name or number the message should be sent from. " +
							"Alphanumeric senderID's are not supported in all countries. " +
							"If alphanumeric, spaces will be ignored. Numbers are specified in E.164 format."),
					 default_value="Check_MK",
                     allow_empty=False,
                 )),
                ],
            ),
        )